@@ -57,22 +57,21 @@ find_inverted_chains <- function(model, trend = 1, plot = FALSE) {
 
   # n_ts x n_years prediction matrix of product of trends and loadings
   flipped_chains <- 0
-  pred0_loadings <- zzz[, 1] # loadings on first trend
-  pred0_trend <- vvv[, 1] # loadings on second trend
+  pred0_loadings <- zzz[, 1]
+  pred0_trend <- vvv[, 1]
   if (nchains > 1) {
     for (i in seq(2, nchains)) {
       pred1_loadings <- zzz[, i]
       pred1_trend <- vvv[, i]
-      # see if flipped trend + loadings are more similar to chain 1 than not flipped
-      if ((sum((-1 * pred1_loadings - pred0_loadings)^2) +
-        sum((-1 * pred1_trend - pred0_trend)^2)) <
-        (sum((pred1_loadings - pred0_loadings)^2) +
-          sum((pred1_trend - pred0_trend)^2))) {
-        # flip this chain -- seems to be something not right with commented out line
-        # flipped_chains <- ifelse(flipped_chains == 0, i, c(flipped_chains, i))
+      # calculate square error of flipped chain versus chain 1 as reference
+      flipped_sq_err <- sum((-1 * zzz[, i] - pred0_loadings)^2) + sum((-1 * vvv[, i] - pred0_trend)^2)
+      sq_err <- sum((zzz[, i] - pred0_loadings)^2) + sum((vvv[, i] - pred0_trend)^2)
+      # if flipped trends/loadings more similar to chain 1, flip
+      if (flipped_sq_err < sq_err) {
         if (flipped_chains == 0) {
           flipped_chains <- i
-        } else {
+        }
+        else {
           flipped_chains <- c(flipped_chains, i)
         }
       }
